@@ -2,7 +2,7 @@
 ##' @aliases prepare_results.pca
 ##' @seealso \code{\link[ade4]{dudi.pca}}
 ##' @import dplyr
-##' @importFrom tidyr gather
+##' @importFrom tidyr pivot_longer
 ##' @importFrom utils head
 ##' @export
 
@@ -38,7 +38,7 @@ prepare_results.pca <- function(obj) {
     vars <- rbind(vars, vars.quanti.sup)
   }
 
-  vars <- vars %>% gather(Axis, Coord, starts_with("Comp")) %>%
+  vars <- vars %>% pivot_longer(names_to = "Axis", values_to = "Coord", starts_with("Comp")) %>%
     mutate(Axis = gsub("Comp", "", Axis, fixed = TRUE),
            Coord = round(Coord, 3))
 
@@ -46,7 +46,7 @@ prepare_results.pca <- function(obj) {
   tmp <- inertia$col.abs
   tmp <- tmp %>% mutate(varname = rownames(tmp),
                         Type = "Active", Class = "Quantitative") %>%
-    gather(Axis, Contrib, starts_with("Axis")) %>%
+    pivot_longer(names_to = "Axis", values_to = "Contrib", starts_with("Axis")) %>%
     mutate(Axis = gsub("^Axis([0-9]+)$", "\\1", Axis),
            Contrib = round(Contrib, 3))
     
@@ -56,7 +56,7 @@ prepare_results.pca <- function(obj) {
   tmp <- abs(inertia$col.rel) / 100
   tmp <- tmp %>% mutate(varname = rownames(tmp),
                         Type = "Active", Class = "Quantitative")
-  tmp <- tmp %>% gather(Axis, Cos2, starts_with("Axis")) %>%
+  tmp <- tmp %>% pivot_longer(names_to = "Axis", values_to = "Cos2", starts_with("Axis")) %>%
     mutate(Axis = gsub("Axis", "", Axis, fixed = TRUE),
            Cos2 = round(Cos2, 3))
   
@@ -77,14 +77,14 @@ prepare_results.pca <- function(obj) {
     tmp_sup$Type <- "Supplementary"
     ind <- ind %>% bind_rows(tmp_sup)
   }
-  ind <- ind %>% gather(Axis, Coord, starts_with("Axis")) %>%
+  ind <- ind %>% pivot_longer(names_to = "Axis", values_to = "Coord", starts_with("Axis")) %>%
     mutate(Axis = gsub("Axis", "", Axis, fixed = TRUE),
            Coord = round(Coord, 3))
 
   ## Individuals contrib
   tmp <- inertia$row.abs
   tmp <- tmp %>% mutate(Name = rownames(tmp), Type = "Active") %>%
-    gather(Axis, Contrib, starts_with("Axis")) %>%
+    pivot_longer(names_to = "Axis", values_to = "Contrib", starts_with("Axis")) %>%
     mutate(Axis = gsub("^Axis([0-9]+)$", "\\1", Axis),
            Contrib = round(Contrib, 3))
   
@@ -95,7 +95,7 @@ prepare_results.pca <- function(obj) {
   tmp$Name <- rownames(tmp)
   tmp$Type <- "Active"
   tmp <- tmp %>%
-    gather(Axis, Cos2, starts_with("Axis")) %>%
+    pivot_longer(names_to = "Axis", values_to = "Cos2", starts_with("Axis")) %>%
     mutate(Axis = gsub("Axis", "", Axis, fixed = TRUE),
            Cos2 = round(Cos2, 3))
   
