@@ -2,7 +2,7 @@
 ##' @aliases prepare_results.prcomp
 ##' @seealso \code{\link{prcomp}}
 ##' @import dplyr
-##' @importFrom tidyr gather
+##' @importFrom tidyr pivot_longer
 ##' @importFrom utils head
 ##' @export
 
@@ -14,7 +14,7 @@ prepare_results.prcomp <- function(obj) {
     vars <- data.frame(vars)
     ## Axes names and inertia
     axes <- seq_len(length(obj$sdev))
-    percent <- round(obj$sdev / sum(obj$sdev) *100, 2)
+    percent <- round(obj$sdev^2 / sum(obj$sdev^2) *100, 2)
     names(axes) <- paste("Axis", axes, paste0("(", percent,"%)"))
     ## Eigenvalues
     eig <- data.frame(dim = 1:length(obj$sdev), percent = percent)
@@ -25,7 +25,7 @@ prepare_results.prcomp <- function(obj) {
     vars$Type <- "Active"
     vars$Class <- "Quantitative"
     
-    vars <- vars %>% gather(Axis, Coord, starts_with("PC")) %>%
+    vars <- vars %>% pivot_longer(names_to = "Axis", values_to = "Coord", starts_with("PC")) %>%
         mutate(Axis = gsub("PC", "", Axis, fixed = TRUE),
                Coord = round(Coord, 3))
 
@@ -43,7 +43,7 @@ prepare_results.prcomp <- function(obj) {
         tmp_sup$Type <- "Supplementary"
         ind <- ind %>% bind_rows(tmp_sup)
     }
-    ind <- ind %>% gather(Axis, Coord, starts_with("PC")) %>%
+    ind <- ind %>% pivot_longer(names_to = "Axis", values_to = "Coord", starts_with("PC")) %>%
         mutate(Axis = gsub("PC", "", Axis, fixed = TRUE),
                Coord = round(Coord, 3))
     ind$Contrib <- NA
